@@ -1,3 +1,4 @@
+DEFINE_TEST(test_7zip_filename_encoding_UTF16_win)
 DEFINE_TEST(test_acl_nfs4)
 DEFINE_TEST(test_acl_pax_posix1e)
 DEFINE_TEST(test_acl_pax_nfs4)
@@ -7,6 +8,7 @@ DEFINE_TEST(test_acl_platform_posix1e_read)
 DEFINE_TEST(test_acl_posix1e)
 DEFINE_TEST(test_acl_from_text)
 DEFINE_TEST(test_acl_to_text)
+DEFINE_TEST(test_ar_mode)
 DEFINE_TEST(test_archive_api_feature)
 DEFINE_TEST(test_archive_clear_error)
 DEFINE_TEST(test_archive_cmdline)
@@ -21,6 +23,7 @@ DEFINE_TEST(test_archive_match_owner)
 DEFINE_TEST(test_archive_match_path)
 DEFINE_TEST(test_archive_match_time)
 DEFINE_TEST(test_archive_pathmatch)
+DEFINE_TEST(test_archive_read_ahead_eof)
 DEFINE_TEST(test_archive_read_add_passphrase)
 DEFINE_TEST(test_archive_read_add_passphrase_incorrect_sequance)
 DEFINE_TEST(test_archive_read_add_passphrase_single)
@@ -46,6 +49,11 @@ DEFINE_TEST(test_archive_set_error)
 DEFINE_TEST(test_archive_string)
 DEFINE_TEST(test_archive_string_sort)
 DEFINE_TEST(test_archive_string_conversion)
+DEFINE_TEST(test_archive_string_conversion_utf16_utf8)
+DEFINE_TEST(test_archive_string_conversion_utf8_utf16)
+DEFINE_TEST(test_archive_string_update_utf8_win)
+DEFINE_TEST(test_archive_string_update_utf8_utf8)
+DEFINE_TEST(test_archive_string_update_utf8_koi8)
 DEFINE_TEST(test_archive_write_add_filter_by_name_b64encode)
 DEFINE_TEST(test_archive_write_add_filter_by_name_bzip2)
 DEFINE_TEST(test_archive_write_add_filter_by_name_compress)
@@ -110,6 +118,7 @@ DEFINE_TEST(test_bad_fd)
 DEFINE_TEST(test_compat_bzip2)
 DEFINE_TEST(test_compat_cpio)
 DEFINE_TEST(test_compat_gtar)
+DEFINE_TEST(test_compat_gtar_large)
 DEFINE_TEST(test_compat_gzip)
 DEFINE_TEST(test_compat_lz4)
 DEFINE_TEST(test_compat_lzip)
@@ -159,7 +168,9 @@ DEFINE_TEST(test_gnutar_filename_encoding_Russian_Russia)
 DEFINE_TEST(test_gnutar_filename_encoding_EUCJP_UTF8)
 DEFINE_TEST(test_gnutar_filename_encoding_EUCJP_CP932)
 DEFINE_TEST(test_gnutar_filename_encoding_CP932_UTF8)
+DEFINE_TEST(test_gnutar_filename_encoding_UTF16_win)
 DEFINE_TEST(test_link_resolver)
+DEFINE_TEST(test_link_resolver_unicode_win)
 DEFINE_TEST(test_open_failure)
 DEFINE_TEST(test_open_fd)
 DEFINE_TEST(test_open_file)
@@ -170,6 +181,7 @@ DEFINE_TEST(test_pax_filename_encoding_EUCJP)
 DEFINE_TEST(test_pax_filename_encoding_CP932)
 DEFINE_TEST(test_pax_filename_encoding_KOI8R_BINARY)
 DEFINE_TEST(test_pax_filename_encoding_KOI8R_CP1251)
+DEFINE_TEST(test_pax_filename_encoding_UTF16_win)
 DEFINE_TEST(test_pax_filename_encoding)
 DEFINE_TEST(test_pax_xattr_header)
 DEFINE_TEST(test_read_data_large)
@@ -182,6 +194,7 @@ DEFINE_TEST(test_read_filter_compress_truncated)
 DEFINE_TEST(test_read_filter_compress_empty2)
 DEFINE_TEST(test_read_filter_compress_invalid)
 DEFINE_TEST(test_read_filter_grzip)
+DEFINE_TEST(test_read_filter_gzip_recursive)
 DEFINE_TEST(test_read_filter_lrzip)
 DEFINE_TEST(test_read_filter_lzop)
 DEFINE_TEST(test_read_filter_lzop_multiple_parts)
@@ -209,6 +222,10 @@ DEFINE_TEST(test_read_format_7zip_ppmd)
 DEFINE_TEST(test_read_format_7zip_lzma2_arm64)
 DEFINE_TEST(test_read_format_7zip_deflate_arm64)
 DEFINE_TEST(test_read_format_7zip_win_attrib)
+DEFINE_TEST(test_read_format_7zip_extract_second)
+DEFINE_TEST(test_read_format_7zip_lzma2_sparc)
+DEFINE_TEST(test_read_format_7zip_zstd_sparc)
+DEFINE_TEST(test_read_format_7zip_deflate_powerpc)
 DEFINE_TEST(test_read_format_7zip_encryption_data)
 DEFINE_TEST(test_read_format_7zip_encryption_header)
 DEFINE_TEST(test_read_format_7zip_encryption_partially)
@@ -218,6 +235,7 @@ DEFINE_TEST(test_read_format_ar)
 DEFINE_TEST(test_read_format_cab)
 DEFINE_TEST(test_read_format_cab_filename)
 DEFINE_TEST(test_read_format_cpio_afio)
+DEFINE_TEST(test_read_format_cpio_afio_broken)
 DEFINE_TEST(test_read_format_cpio_bin)
 DEFINE_TEST(test_read_format_cpio_bin_Z)
 DEFINE_TEST(test_read_format_cpio_bin_be)
@@ -262,6 +280,7 @@ DEFINE_TEST(test_read_format_gtar_gz)
 DEFINE_TEST(test_read_format_gtar_lzma)
 DEFINE_TEST(test_read_format_gtar_sparse)
 DEFINE_TEST(test_read_format_gtar_sparse_skip_entry)
+DEFINE_TEST(test_read_format_huge_rpm)
 DEFINE_TEST(test_read_format_iso_Z)
 DEFINE_TEST(test_read_format_iso_multi_extent)
 DEFINE_TEST(test_read_format_iso_xorriso)
@@ -361,6 +380,15 @@ DEFINE_TEST(test_read_format_rar5_sfx)
 DEFINE_TEST(test_read_format_rar5_decode_number_out_of_bounds_read)
 DEFINE_TEST(test_read_format_rar5_bad_window_size_in_multiarchive_file)
 DEFINE_TEST(test_read_format_rar5_read_data_block_uninitialized_offset)
+DEFINE_TEST(test_read_format_rar5_data_ready_pointer_leak)
+DEFINE_TEST(test_read_format_rar4_encrypted)
+DEFINE_TEST(test_read_format_rar4_encrypted_filenames)
+DEFINE_TEST(test_read_format_rar4_solid_encrypted)
+DEFINE_TEST(test_read_format_rar4_solid_encrypted_filenames)
+DEFINE_TEST(test_read_format_rar5_encrypted)
+DEFINE_TEST(test_read_format_rar5_encrypted_filenames)
+DEFINE_TEST(test_read_format_rar5_solid_encrypted)
+DEFINE_TEST(test_read_format_rar5_solid_encrypted_filenames)
 DEFINE_TEST(test_read_format_rar_encryption_data)
 DEFINE_TEST(test_read_format_rar_encryption_header)
 DEFINE_TEST(test_read_format_rar_encryption_partially)
@@ -374,6 +402,7 @@ DEFINE_TEST(test_read_format_tar_empty_pax)
 DEFINE_TEST(test_read_format_tar_empty_with_gnulabel)
 DEFINE_TEST(test_read_format_tar_filename)
 DEFINE_TEST(test_read_format_tar_invalid_pax_size)
+DEFINE_TEST(test_read_format_tar_pax_large_attr)
 DEFINE_TEST(test_read_format_tbz)
 DEFINE_TEST(test_read_format_tgz)
 DEFINE_TEST(test_read_format_tlz)
@@ -382,6 +411,8 @@ DEFINE_TEST(test_read_format_tz)
 DEFINE_TEST(test_read_format_ustar_filename)
 DEFINE_TEST(test_read_format_warc)
 DEFINE_TEST(test_read_format_xar)
+DEFINE_TEST(test_read_format_xar_duplicate_filename_node)
+DEFINE_TEST(test_read_format_xar_doublelink)
 DEFINE_TEST(test_read_format_zip)
 DEFINE_TEST(test_read_format_zip_ppmd_one_file)
 DEFINE_TEST(test_read_format_zip_ppmd_one_file_blockread)
@@ -487,10 +518,12 @@ DEFINE_TEST(test_ustar_filename_encoding_Russian_Russia)
 DEFINE_TEST(test_ustar_filename_encoding_EUCJP_UTF8)
 DEFINE_TEST(test_ustar_filename_encoding_EUCJP_CP932)
 DEFINE_TEST(test_ustar_filename_encoding_CP932_UTF8)
+DEFINE_TEST(test_ustar_filename_encoding_UTF16_win)
 DEFINE_TEST(test_ustar_filenames)
 DEFINE_TEST(test_warn_missing_hardlink_target)
 DEFINE_TEST(test_write_disk)
 DEFINE_TEST(test_write_disk_appledouble)
+DEFINE_TEST(test_write_disk_appledouble_zip)
 DEFINE_TEST(test_write_disk_failures)
 DEFINE_TEST(test_write_disk_fixup)
 DEFINE_TEST(test_write_disk_hardlink)
@@ -504,6 +537,7 @@ DEFINE_TEST(test_write_disk_secure744)
 DEFINE_TEST(test_write_disk_secure745)
 DEFINE_TEST(test_write_disk_secure746a)
 DEFINE_TEST(test_write_disk_secure746b)
+DEFINE_TEST(test_write_disk_secure_noabsolutepaths)
 DEFINE_TEST(test_write_disk_sparse)
 DEFINE_TEST(test_write_disk_symlink)
 DEFINE_TEST(test_write_disk_times)
@@ -590,6 +624,7 @@ DEFINE_TEST(test_write_format_zip_file)
 DEFINE_TEST(test_write_format_zip_file_zip64)
 DEFINE_TEST(test_write_format_zip_large)
 DEFINE_TEST(test_write_format_zip_stream)
+DEFINE_TEST(test_write_format_zip_windows_path)
 DEFINE_TEST(test_write_format_zip_zip64_oversize)
 DEFINE_TEST(test_write_open_memory)
 DEFINE_TEST(test_write_read_format_zip)
@@ -603,3 +638,4 @@ DEFINE_TEST(test_zip_filename_encoding_ru_RU_CP1251)
 DEFINE_TEST(test_zip_filename_encoding_Russian_Russia)
 DEFINE_TEST(test_zip_filename_encoding_EUCJP)
 DEFINE_TEST(test_zip_filename_encoding_CP932)
+DEFINE_TEST(test_zip_filename_encoding_UTF16_win)
